# GaterAid
_To abate the strait of applying a two-qubit gate to a quantum state, look no further!_

The GaterAid package provides a simple and intuitive interface for applying common and customisable two-qubit gates to quantum states. In particular, it consists of the following modules:

* ``controlled_gates``: provides a selection of common controlled gates, as well as simple cutomisation for controlled gates.
* ``gate_base``: provides the base class for all two-qubit gates.
* ``other_gates``: provides a selection of common two-qubit gates, as well as simple customisation for local and general gates.
* ``quantum_state``: provides the base class for all two-qubit quantum states.
* ``utilities``: provides utility functions for the package.

Documentation for the package can be found [here](https://tinyurl.com/y65m7tcm). Alternatively, consult [example.ipynb](https://github.com/QC2-python-SE/QWACOBEC/blob/main/example.ipynb) for explicit examples and guidance on using the package.

Installation
------------

GaterAid is hosted on PyPi. Simply use pip to install:

```
   pip install GaterAid
```

----

QWACOBEC LLC.
-------------

CEO: Eleanor Kneip

Office Manager: Stasiu Wolanski

Intern (in training): Joel Mills
